using System;
using System.Web;
using System.Drawing;
using System.IO;

using MindFusion.Diagramming;
using MindFusion.Diagramming.WebForms;
using SolidBrush = MindFusion.Drawing.SolidBrush;


public partial class _Default : System.Web.UI.Page 
{

    protected void Page_Load(object sender, EventArgs e)
    {
		Diagram diagram = diagramView.Diagram;
        Response.Cache.SetCacheability(HttpCacheability.NoCache);
        if (!IsPostBack)
        {
			if (File.Exists(FlowChartFile))
			{
				diagram.LoadFromXml(FlowChartFile);
			}
			else
			{
				diagram.BackgroundImageUrl = "Map.png";
				diagram.DefaultShape = Shape.FromId("Junction");
				diagramView.Behavior = Behavior.DrawLinks;
				diagram.DynamicLinks = true;

				diagram.BackBrush = new MindFusion.Drawing.SolidBrush(Color.White);

				DiagramStyle style = new DiagramStyle();
				style.FontFamily = "Verdana";
				style.FontSize = 9;
				diagram.Style = style;

				diagram.ShapeNodeStyle.Brush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.Yellow));
				diagram.DiagramLinkStyle.Brush = new MindFusion.Drawing.SolidBrush(Color.Black);

				diagram.LinkHeadShape = ArrowHeads.Triangle;
				diagram.LinkHeadShapeSize = 1;
			}

			diagram.LinkHitDistance = 2;
		}

		CheckBoxImageVisible.Checked = diagram.BackgroundImageUrl != null;
    }

    protected void Button1_Click(object sender, EventArgs e)
    {
		diagramView.Diagram.SaveToXml(FlowChartFile);
    }

    public string FlowChartFile
    {
        get { return MapPath("saved.xml"); }
    }

	protected void OnImageMap(object sender, EventArgs e)
	{
        diagramView.ZoomFactor = 100;
		diagramView.ClientSideMode = ClientSideMode.ImageMap;
	}

	protected void OnCanvas(object sender, EventArgs e)
	{
        diagramView.ZoomFactor = 100;
        diagramView.ClientSideMode = ClientSideMode.Canvas;
	}
}