﻿shapeSize = 4;
labelWidth = 20;
backgroundImage = null;

function onAppletStarted()
{
	var view = $find("diagramView");

	if (view)
	{
		document.getElementById('currentZoom').innerHTML = view.getZoomFactor();
		setShapeSize(shapeSize);
		updateCheckBoxImageVisible();
		backgroundImage = view.getBackgroundImageUrl();
	}

	$('#shapeSize').slider("option", "value", shapeSize);
}

function onLinkCreated(diagram, args)
{
	args.getLink().putEndPointsAtNodeBorders();
}

function onLinkDoubleClicked(diagram, args)
{
	var link = args.getLink();
	link.setSegmentCount(link.getSegmentCount() + 1);
}

// allow attaching of labels to junctions by double clicking on them
function onNodeDoubleClicked(diagram, args)
{
    var nodeToEdit = null;
    var node = args.getNode();
    if (node.getShape().getId() == "Junction")
    {
        // create label if not exists
        if (node.getAttachedNodes().length == 0)
        {
            var junctionBounds = node.getBounds();
            
            var label = diagram.getFactory().createShapeNode(
				junctionBounds.center().x - labelWidth/2,
                junctionBounds.y - shapeSize,
                labelWidth, shapeSize + 1);

            label.setShape("Rectangle");
            label.setRotateText(true);
			label.setTransparent(true);
            label.setHandlesStyle(MindFusion.Diagramming.HandlesStyle.SquareHandles);
			label.setEnabledHandles(MindFusion.Diagramming.AdjustmentHandles.All);
            label.attachTo(node);
        }

        var attachedItems = node.getAttachedNodes();
        nodeToEdit = attachedItems[0];
    }
    else
        nodeToEdit = node;

    if (nodeToEdit)
    	diagram.beginEdit(nodeToEdit);
}

function onDiagramClicked(diagram, args)
{
	var x = args.mousePosition.x;
	var y = args.mousePosition.y;
	if (args.mouseButton == 0)
    {
        var ss2 = shapeSize / 2.0;
        var node = diagram.getFactory().createShapeNode(
            x - ss2, y - ss2, shapeSize, shapeSize);
		node.setHandlesStyle(MindFusion.Diagramming.HandlesStyle.MoveOnly);
    }
     else if (args.mouseButton == 2)
    {
        // right button unselects all
        diagram.getSelection().clear();
    }
}

function updateCheckBoxImageVisible()
{
	var view = $find('diagramView');
	if (view)
		document.getElementById('CheckBoxImageVisible').checked = view.getBackgroundImageUrl() != null;
}


// allow setting of shape size independently of zooming
function setShapeSize(shapeSize)
{
	var view = $find('diagramView');

	if (!view) return;

	view.setFont(new MindFusion.Drawing.Font('Verdana', shapeSize * 0.9));
	view.setAdjustmentHandlesSize(shapeSize / 3.0);

	var nodes = view.getNodes();
    for (var i = nodes.length - 1; i >= 0; --i)
    {
        var node = nodes[i];
        if (node.getShape().id == "Junction")
        {
            // make old center == new center
            var b = node.getBounds();
            var newX = b.x + b.width/2.0 - shapeSize/2.0;
            var newY = b.y + b.height/2.0 - shapeSize/2.0;
            node.setBounds(new MindFusion.Drawing.Rect(newX, newY, shapeSize, shapeSize));
        }
    }
	var links = view.getLinks();
    for (var i = links.length - 1; i >= 0; --i)
    {
        var link = links[i];
        link.setHeadShapeSize(shapeSize/2.0);
    }
    window.shapeSize = shapeSize;
}

// event handler, resize all shapes
function shapeSizeOnChange(input)
{
    if (input.value.length > 0 && input.value > 0)
        setShapeSize(input.value);
}

function imageUrlChange(input)
{
    var view = $find('diagramView')
    if (!view) return;
    var url = input.value;
    if (url && url.length > 0) {
    	view.setBackgroundImageUrl(url);
    	view.repaint();
    } else {
    	view.setBackgroundImageUrl(null);
    	view.repaint();
    }
}

function zoomIn()
{
	var view = $find('diagramView');
	if (view)
	{
		if (view.getZoomFactor() < 300)
		{
			view.setZoomFactor(view.getZoomFactor() + 50);
			document.getElementById('currentZoom').innerHTML = view.getZoomFactor();
		}
	}
}

function zoomOut()
{
	var view = $find('diagramView');
	if (view)
	{
		if (view.getZoomFactor() > 50)
		{
			view.setZoomFactor(view.getZoomFactor() - 50);
			document.getElementById('currentZoom').innerHTML = view.getZoomFactor();
		}
	}
}

function setImageVisibility(visible)
{
	var view = $find('diagramView');
	if (view)
	{
		view.setBackgroundImageUrl(visible ? backgroundImage : null);
		view.repaint();
	}
}